@@ -284,7 +284,7 @@ void *  Safe_calloc  (size_t N, size_t Len)
    P = calloc (N, Len);
    if  (P == NULL)
        {
-        fprintf (stderr, "ERROR:  calloc failed\n");
+	 fprintf (stderr, "ERROR:  calloc failed for N=%d Len=%d\n",N,Len);
         exit (EXIT_FAILURE);
        }
 
